latch-curate
===

## Quickstart

Create on directory for each curation project/dataset and run the following
commands in this project directory.

```
latch-curate download run <gse-id>
latch-curate construct-counts run
latch-curate qc run
latch-curate transform run
latch-curate type-cells run
latch-curate harmonize-metadata run
```
